Class: Google::Cloud::Workflows::V1::ListWorkflowRevisionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workflows/v1/workflows.rb

Overview

Request for the ListWorkflowRevisions method.

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ ::String

Returns Required. Workflow for which the revisions should be listed. Format: projects/{project}/locations/{location}/workflows/{workflow}.

Returns:

  • (::String) —

    Required. Workflow for which the revisions should be listed. Format: projects/{project}/locations/{location}/workflows/{workflow}



390
391
392
393
# File 'proto_docs/google/cloud/workflows/v1/workflows.rb', line 390

class ListWorkflowRevisionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size ⇒ ::Integer

Returns The maximum number of revisions to return per page. If a value is not specified, a default value of 20 is used. The maximum permitted value is 100. Values greater than 100 are coerced down to 100.

Returns:

  • (::Integer) —

    The maximum number of revisions to return per page. If a value is not specified, a default value of 20 is used. The maximum permitted value is 100. Values greater than 100 are coerced down to 100.



390
391
392
393
# File 'proto_docs/google/cloud/workflows/v1/workflows.rb', line 390

class ListWorkflowRevisionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token ⇒ ::String

Returns The page token, received from a previous ListWorkflowRevisions call. Provide this to retrieve the subsequent page.

Returns:

  • (::String) —

    The page token, received from a previous ListWorkflowRevisions call. Provide this to retrieve the subsequent page.



390
391
392
393
# File 'proto_docs/google/cloud/workflows/v1/workflows.rb', line 390

class ListWorkflowRevisionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end